@@ -603,7 +603,7 @@ struct threshold_record
 
 #define	SORT_PREFIX(x) threshold_##x
 #define	SORT_KEY_REGULAR struct threshold_record
-#define SORT_DATA_LEN(k) ((k).url_len)
+#define SORT_DATA_SIZE(k) ((k).url_len)
 #define	SORT_INPUT_FILE
 #define	SORT_OUTPUT_FB
 
