@@ -57,7 +57,7 @@ stem_dict_conv_in(struct dict_stemmer *ts, const byte *src, byte *dest)
 	break;
       if (Uupper(u))
 	u = Utolower(u);
-      else if (!Ulower(u))
+      else if (!Ualpha(u))
 	return 0;
       if (dest > dest_end)
 	return 0;
