@@ -43,9 +43,15 @@ typedef u32 oid_t;			/* Object ID */
 
 /* Area ID's */
 
+#ifdef CONFIG_AREAS
+typedef u32 area_t;
+#define AREA_NONE 0
+#define AREA_ANY ~0U
+#else
 typedef struct { } area_t;
 #define AREA_NONE (area_t){}
 #define AREA_ANY (area_t){}
+#endif
 
 /* An alias for the libucw logging function */
 
